
# Type: entity to phenotypic feature association_object




URI: [biolink:entity_to_phenotypic_feature_association_object](https://w3id.org/biolink/vocab/entity_to_phenotypic_feature_association_object)


## Domain and Range

[EntityToPhenotypicFeatureAssociation](EntityToPhenotypicFeatureAssociation.md) ->  <sub>REQ</sub> [PhenotypicFeature](PhenotypicFeature.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [EntityToPhenotypicFeatureAssociation](EntityToPhenotypicFeatureAssociation.md)
